import { TestScheduler } from 'rxjs/testing';
/** @hidden */
declare global {
    interface SymbolConstructor {
        readonly observable: symbol;
    }
}
/** @hidden */
declare type Run = Parameters<TestScheduler['run']>[0];
/** @hidden */
declare type Helpers = Parameters<Run>[0];
/** @hidden */
declare type Callback<T> = (testHelpers: Helpers & {
    testScheduler: TestScheduler;
}) => T;
/**
 * A helper to take some boilerplate out of RxJS's new marble testing API for jasmine.
 *
 * ```ts
 * it("doubles numbers", marbleTest(({ cold, expectObservable }) => {
 *   const source = cold("-1-2-3-|");
 *   const expected = "   -2-4-6-|");
 *   expectObservable(source.pipe(double())).toBe(expected);
 * }));
 * ```
 */
export declare function marbleTest<T>(callback: Callback<T>): () => T;
export {};
