/**
 * The type for component harness used in an `AngularContext`, which wraps the original harness in a proxy meant to be used in a `fakeAsync` test where one cannot `await` the results of an asynchronous call. The functions that would normally return a promise instead return their result immediately, calling `tick()` to flush it first.
 */
export declare type Synchronized<O extends object> = {
    [K in keyof O]: O[K] extends (...args: any[]) => any ? SynchronizedFunction<O[K]> : O[K];
};
/** @hidden */
declare type SynchronizedFunction<F extends (...args: any[]) => any> = (...args: Parameters<F>) => SynchronizedResult<ReturnType<F>>;
/** @hidden */
declare type SynchronizedResult<V> = V extends PromiseLike<any> ? SynchronizedPromise<V> : V extends object ? Synchronized<V> : V;
/** @hidden */
declare type SynchronizedPromise<P> = P extends PromiseLike<infer R> ? R extends object ? Synchronized<R> : R : 'assertion error';
/** @hidden */
export declare function synchronize<T extends object>(obj: T): Synchronized<T>;
export {};
